@@ -46,6 +46,7 @@ void SettingsDialog::on_listWidget_itemPressed(QListWidgetItem* item)
     {
         m_ui->url->setText(p->address);
         m_ui->horizontalSlider->setValue( p->updateIntervall );
+        m_ui->updateWhenClicked->setChecked( p->updateWhenClicked );
         currentItem = item;
     }
 }
@@ -94,7 +95,10 @@ void SettingsDialog::saveItems()
 /** Refreshrate changed */
 void SettingsDialog::on_horizontalSlider_valueChanged(int value)
 {
-    m_ui->refreshRate->setText( QString("%1").arg(value) );
+    double d = (double)value/10;
+    QString str;
+    str.sprintf("%.1f", d);
+    m_ui->refreshRate->setText( str );//QString("%f").arg(d, 0, 'f', 1) );
     m_ui->buttonSaveUrl->setEnabled(true);
 
 }
@@ -107,6 +111,9 @@ void SettingsDialog::on_buttonRemove_clicked()
         FindByNick( currentItem->text(), index );
         delete m_ui->listWidget->takeItem( index ); //!< @bug this not working!
         m_pCamList->removeAt( index );
+        currentItem = 0;
+        m_ui->listWidget->setCurrentRow(0);
+        m_ui->buttonSaveUrl->setEnabled(false);
     }
 }
 /** button new clicked */
@@ -120,6 +127,7 @@ void SettingsDialog::on_buttonNew_clicked()
         m_ui->listWidget->addItem( text );
         m_pCamList->append( Cam_s(text, address) );
         currentItem = m_ui->listWidget->item( m_ui->listWidget->count()-1 );
+        m_ui->buttonSaveUrl->setEnabled(false);
     }
 }
 /** event url edited
@@ -132,16 +140,29 @@ void SettingsDialog::on_url_textEdited(QString newUrl)
 /** button Save URL+update intervall clicked */
 void SettingsDialog::on_buttonSaveUrl_clicked()
 {
-    m_ui->buttonSaveUrl->setEnabled(false);
     if(currentItem==0)return;
 
+
     Cam_s *p = (Cam_s*)FindByNick( currentItem->text() );
     if(p)
     {
         p->address = m_ui->url->text(); //url
         p->updateIntervall = m_ui->horizontalSlider->value();   //update intervall
+        p->updateWhenClicked = m_ui->updateWhenClicked->checkState();
+        m_ui->buttonSaveUrl->setEnabled(false);
     }
 
 }
 
 
+
+void SettingsDialog::on_checkBox_clicked(bool checked)
+{
+    if(currentItem==0)return;
+    Cam_s *p = (Cam_s*)FindByNick( currentItem->text() );
+    if(p)
+    {
+        p->updateWhenClicked = checked;
+        m_ui->buttonSaveUrl->setEnabled(true);
+    }
+}
