@@ -11,11 +11,12 @@
 **
 ****************************************************************************/
 #include "widget.h"
-#include <QtSvg/QSvgRenderer>
 
+//#include <QtSvg/QSvgRenderer>
+//#include <QMovie>
+//#include <libnotify/notify.h>
 
-//#include <notify.h>
-
+#include <QtDBus>
 #include <QPainter>
 #include <QPaintEvent>
 #include <QPen>
@@ -62,7 +63,7 @@ Widget::Widget()
     QCoreApplication::instance()->setApplicationName(name);
 
     /* Init libnotify library */
-    //notify_init(name);
+
 
     // Get required atoms
     Atom winTypeAtom = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false);
@@ -90,18 +91,18 @@ Widget::Widget()
     runButton->setChecked(false);
     runButton->setFixedSize(90, 50);
     runButton->setFont( QFont( "lucida", 14, QFont::Bold, FALSE ) );
-    runButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  border-color: #0c457e;");
+    runButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  border-color: #0c457e; color: black;");
 
 
     nextButton = new QPushButton(tr("next"));
     nextButton->setFixedSize(90, 50);
     nextButton->setFont( QFont( "lucida", 14, QFont::Bold, FALSE ) );
-    nextButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  border-color: #0c457e;");
+    nextButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  border-color: #0c457e; color: black;");
 
     prevButton = new QPushButton(tr("prev"));
     prevButton->setFixedSize(90, 50);
     prevButton->setFont( QFont( "lucida", 14, QFont::Bold, FALSE ) );
-    prevButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  border-color: #0c457e;");
+    prevButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  border-color: #0c457e; color: black;");
 
     /*
     progressSlider = new QSlider( Qt::Vertical );
@@ -159,13 +160,11 @@ Widget::Widget()
     QCoreApplication::setOrganizationName("JuPe");
     QCoreApplication::setOrganizationDomain("http://webcamviewer.garage.maemo.org");
     QCoreApplication::setApplicationName("Webcam Viewer");
-    this->setWindowTitle("Webcam viewer");
+    this->setWindowTitle("Webcam Viewer");
 
     m_settings = new QSettings("Webcamviewer", "webcamviewer");
 
 
-
-
     //m_settings->clear();
 
     int size = m_settings->beginReadArray("cams");
@@ -176,6 +175,7 @@ Widget::Widget()
                     m_settings->value("username").toString(),
                     m_settings->value("password").toString(),
                     m_settings->value("updateIntervall").toInt(),
+                    m_settings->value("updateWhenClicked").toBool(),
                     QByteArray::fromBase64( m_settings->value("lastImage").toByteArray())
                     );
          m_camList.append(cam);
@@ -189,7 +189,6 @@ Widget::Widget()
          m_camList.append( Cam_s( tr("Oulu - Nallikari"),        tr("http://weathercam.vaisala.net/banner/weather.aspx?id=nallikari") ) );
      }
 
-     //m_refreshInterval = m_settings->value("refreshInterval", 10).toInt();   //default 1s
      //Current camera index from list
      m_currentCamIndex = m_settings->value("current", 0).toInt();
      m_pImageData = m_currentCamIndex==-1? 0 : &(m_camList.at(m_currentCamIndex).lastImage);
@@ -207,9 +206,9 @@ Widget::~Widget()
         m_settings->setValue("password", m_camList.at(i).username);
         m_settings->setValue("updateIntervall", m_camList.at(i).updateIntervall);
         m_settings->setValue("lastImage", m_camList.at(i).lastImage.toBase64() );
+        m_settings->setValue("updateWhenClicked", m_camList.at(i).updateWhenClicked);
     }
     m_settings->endArray();
-    m_settings->setValue( tr("refreshInterval"), m_refreshInterval);
     m_settings->setValue(tr("current"), m_currentCamIndex);
     m_settings->sync();
     delete m_settings;
@@ -226,16 +225,21 @@ void Widget::activateConnection(bool toggle)
     refreshLabels(toggle);
     if(toggle)
     {
-        //timer->start( m_refreshInterval*100 );
         timer->start( m_camList.at(m_currentCamIndex).updateIntervall*100 );
         //runButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  border-color: #0c457e;");
 
+        showInformationNote("Connection enabled");
+
+        update();
+
+
     }
     else
     {
         //runButton->setStyleSheet("border-width: 1px;border-style: outset;border-radius: 14px;  background-color: white;");
         timer->stop();
-
+        showInformationNote("Connection disabled");
+        update();
 
         /*
         NotifyNotification *notification;
@@ -278,7 +282,8 @@ void Widget::timerHandler()
 {
     //Be sure that there's no previous download processes.
     if(!m_loadingInProcess && m_currentCamIndex>=0 &&
-        m_currentCamIndex < m_camList.size() )
+        m_currentCamIndex < m_camList.size() &&
+        !m_camList.at(m_currentCamIndex).updateWhenClicked )
     {
         //download image from url
         downloadFile( m_camList.at (m_currentCamIndex).address );
@@ -329,8 +334,6 @@ void Widget::changeCamera()
 
     m_cameraChangedWhenLoadingProcess = this->m_loadingInProcess?true:false;
 
-
-
     timerInfo->start(m_showInfoTimeout);
     m_showInfo=True;
 
@@ -338,25 +341,42 @@ void Widget::changeCamera()
     if( m_currentCamIndex == m_camList.size()-1 )
     {
         nextButton->setEnabled(false);
+        nextButton->setText("");
+    }
+    else{
+        nextButton->setEnabled(true);
+        nextButton->setText("next");
     }
-    else nextButton->setEnabled(true);
 
     //Check if current is first camera in list
     if( m_currentCamIndex == 0 )
     {
         prevButton->setEnabled(false);
+        prevButton->setText("");
+    }
+    else{
+        prevButton->setEnabled(true);
+        prevButton->setText("prev");
     }
-    else prevButton->setEnabled(true);
 
+    /*
     if(!m_loadingInProcess)
-        update();
+        update();*/
+
+    if( m_camList.at(m_currentCamIndex).updateWhenClicked )
+    {
+        runButton->setEnabled( false );
+    }
+    else
+    {
+        runButton->setEnabled( true );
+        if( runButton->isChecked() )
+            timer->start( m_camList.at(m_currentCamIndex).updateIntervall*100 );
+    }
 
-    //timer->start( m_refreshInterval*100 );
 
     m_pImageData = &m_camList.at(m_currentCamIndex).lastImage;
 
-    //this->repaint();
-
     update();
 
 }
@@ -409,7 +429,6 @@ void Widget::downloadProgress(qint64 bytesRead,qint64 totalBytes)
 {
     //progressSlider->setValue( bytesRead / totalBytes * 100 );
 }
-
 /**
   Paint event (QWidget)
   */
@@ -471,6 +490,13 @@ void Widget::paintEvent(QPaintEvent *e)
         pPainter.drawText( QPoint(80,40), m_camList.at(m_currentCamIndex).nick );
     }
 
+    if( timer->isActive() )
+    {
+        pPainter.setBrush( Qt::red );
+        pPainter.setBackgroundMode( Qt::OpaqueMode );
+        pPainter.drawEllipse(370, 10, 7, 7);
+    }
+
 //    QPainter p(this);
 //    p.setRenderHint(QPainter::Antialiasing);
 //    p.setClipRect(e->rect());
@@ -524,7 +550,16 @@ void Widget::mouseDoubleClickEvent( QMouseEvent * event )
         }
     }
 }
-
+/** If clicked & updateWhenClick enabled -> update cam */
+void Widget::mousePressEvent( QMouseEvent * event )
+{
+    if(!m_loadingInProcess && m_currentCamIndex>=0 &&
+        m_currentCamIndex < m_camList.size() )
+    {
+        //download image from url
+        downloadFile( m_camList.at (m_currentCamIndex).address );
+    }
+}
 /**
 
     x11 Event handler.
@@ -590,3 +625,26 @@ void Widget::resizeEvent(QResizeEvent *e)
 	Q_UNUSED(h);
     }
 }
+void Widget::showInformationNote(QString info_type)
+{
+
+    //hildon_banner_show_information(NULL, NULL,"hello");
+}
+void Widget::showAboutNote(QString info_type){
+    QString credits = "\n\nCredits:\n\nProgramming: Jussi Vatjus-Anttila\n";
+
+    QDBusMessage msg = QDBusMessage::createMethodCall("org.freedesktop.Notifications",
+                                                      "/org/freedesktop/Notifications",
+                                                      "org.freedesktop.Notifications",
+                                                      "SystemNoteDialog");
+    QString text = info_type + credits;
+
+    QList<QVariant> args;
+    args.append(text);
+    args.append(static_cast<quint32>(0));
+    args.append("ok");
+
+    msg.setArguments(args);
+
+    QDBusConnection::systemBus().call(msg);
+}
